@@ -1,13 +1,13 @@
 package Email::Sender::Transport::Mbox;
 # ABSTRACT: deliver mail to an mbox on disk
-$Email::Sender::Transport::Mbox::VERSION = '1.300017'; # TRIAL
+$Email::Sender::Transport::Mbox::VERSION = '1.300019'; # TRIAL
 use Moo;
 with 'Email::Sender::Transport';
 
 use Carp;
 use File::Path;
 use File::Basename;
-use IO::File;
+use IO::File 1.11; # binmode
 use Email::Simple 1.998;  # needed for ->header_obj
 use Fcntl ':flock';
 
@@ -126,7 +126,7 @@ Email::Sender::Transport::Mbox - deliver mail to an mbox on disk
 
 =head1 VERSION
 
-version 1.300017
+version 1.300019
 
 =head1 DESCRIPTION
 
