@@ -1,6 +1,6 @@
 package Email::Sender::Transport::SMTP;
 # ABSTRACT: send email over SMTP
-$Email::Sender::Transport::SMTP::VERSION = '1.300017'; # TRIAL
+$Email::Sender::Transport::SMTP::VERSION = '1.300019'; # TRIAL
 use Moo;
 
 use Email::Sender::Failure::Multi;
@@ -212,10 +212,15 @@ sub send_email {
   while (length $msg_string) {
     my $next_hunk = substr $msg_string, 0, $hunk_size, '';
 
-    # I would love to remove this when Net::SMTP is unscrewed.
-    # See https://rt.cpan.org/Ticket/Display.html?id=104433
-    # -- rjbs, 2015-05-14
-    utf8::downgrade($next_hunk);
+    # For the need to downgrade, see
+    #   https://rt.cpan.org/Ticket/Display.html?id=104433
+    #
+    # The ||0 is there because when we've mocked Net::SMTP, there is no
+    # version.  We can't get the ->VERSION call to hit the mock, because we get
+    # the mock from ->new.  We don't want to create a new SMTP just to get the
+    # version, and we can't rely on $smtp being a Net::SMTP object.
+    # -- rjbs, 2015-08-10
+    utf8::downgrade($next_hunk) if (Net::SMTP->VERSION || 0) < 3.07;
 
     $smtp->datasend($next_hunk) or $FAULT->("error at during DATA");
   }
@@ -275,7 +280,7 @@ Email::Sender::Transport::SMTP - send email over SMTP
 
 =head1 VERSION
 
-version 1.300017
+version 1.300019
 
 =head1 DESCRIPTION
 
